@@ -1,10 +1,11 @@
-import builtins
 import logging
 import os
 import warnings
 from socket import gethostname
-from typing import Optional, Type
+from typing import Optional, Type, TypeVar
 
+import builtins
+import yaml
 from pydantic import ValidationError
 from pydantic.main import BaseModel
 
@@ -47,6 +48,37 @@ def get(key: str, default: Optional[str] = "") -> str:
     return os.environ.get(key, default)
 
 
+_inside_docker_cached = None
+
+
+def _inside_docker():
+    global _inside_docker_cached
+    if _inside_docker_cached is not None:
+        return _inside_docker_cached
+    else:
+        if os.path.exists('/.dockerenv'):
+            _inside_docker_cached = True
+            return _inside_docker_cached
+
+        path = '/proc/self/cgroup'
+        if os.path.isfile(path):
+            with open(path, "r") as f:
+                _inside_docker_cached = any('docker' in line for line in f)
+        else:
+            _inside_docker_cached = False
+
+        return _inside_docker_cached
+
+
+def debug():
+    if "DEBUG" in os.environ:
+        return bool("DEBUG", default=False)
+    elif testing():
+        return False
+    else:
+        return version() == "unknown" and not _inside_docker()
+
+
 def log_level() -> int:
     log_levels = {
         "INFO": logging.INFO,
@@ -60,7 +92,8 @@ def log_level() -> int:
         "CRIT": logging.CRITICAL,
         "FATAL": logging.FATAL
     }
-    return log_levels.get(os.environ.get("LOG_LEVEL", "INFO").upper(), logging.INFO)
+    default_log_level = logging.DEBUG if debug() else logging.INFO
+    return log_levels.get(os.environ.get("LOG_LEVEL", "").upper(), default_log_level)
 
 
 def version() -> str:
@@ -123,15 +156,47 @@ def validate_config_module(config):
         )
 
 
-def yaml(model: Type[BaseModel], path: str = None):
-    yaml_path = path or string("CONFIG_YAML", "/data/config.yml")
+class SafeLoaderIgnoreUnknown(yaml.SafeLoader):
+    def ignore_unknown(self, node):
+        return None
+
+
+SafeLoaderIgnoreUnknown.add_constructor(None, SafeLoaderIgnoreUnknown.ignore_unknown)
+
+YamlType = TypeVar("YamlType", bound=BaseModel)
+
+
+def yaml(model: Type[YamlType], path: str = None) -> YamlType:
+    yaml_path = path or string("CONFIG_YAML", "")
+    if not yaml_path:
+        if debug():
+            yaml_path = "../settings/default-debug.yml"
+        elif testing():
+            yaml_path = "../settings/default-testing.yml"
+        else:
+            yaml_path = "/data/config.yml"
+
     try:
         if os.path.exists(yaml_path):
             import yaml
             with open(yaml_path, "r") as f:
-                return model(**yaml.safe_load(f))
+                a = yaml.load(f, SafeLoaderIgnoreUnknown)
+                return model.parse_obj(a)
         else:
             return model()
     except ValidationError as e:
         logging.exception("error during config yaml loading, something is wrong with the configuration")
         raise e from None
+
+
+def testing():
+    return bool("TESTING", False)
+
+
+def database_folder():
+    path = string("DATABASE_FOLDER", f"../sqlite/")
+    if testing():
+        path += "test/"
+    elif debug():
+        path += "debug/"
+    return path
