@@ -8,6 +8,7 @@ import zmq
 
 from openmodule.alert import AlertHandler
 from openmodule.config import validate_config_module
+from openmodule.database.database import Database
 from openmodule.dispatcher import SubscribingMessageDispatcher
 from openmodule.health import HealthHandlerType, Healthz, HealthPingMessage
 from openmodule.logging import init_logging
@@ -18,6 +19,8 @@ from openmodule.threading import get_thread_wrapper
 
 
 class OpenModuleCore(threading.Thread):
+    database = None
+
     def __init__(self, context, config):
         super().__init__(target=get_thread_wrapper(self._run))
         self.context = context
@@ -33,7 +36,6 @@ class OpenModuleCore(threading.Thread):
         self.log = logging.getLogger(self.__class__.__name__)
         self.health = Healthz(self)
         self.alerts = AlertHandler(self)
-
         self.messages.register_handler(b"healthz", HealthPingMessage, self.health.process_message,
                                        filter={"type": "ping"})
 
@@ -41,6 +43,12 @@ class OpenModuleCore(threading.Thread):
         with self.sub_lock:
             self.sub_socket.subscribe(topic)
 
+    def init_database(self):
+        if self.config.TESTING:
+            self.database = Database(self.config.DATABASE_FOLDER, self.config.NAME, alembic_path="../src/database")
+        else:
+            self.database = Database(self.config.DATABASE_FOLDER, self.config.NAME)
+
     def _run(self):
         try:
             while True:
@@ -69,9 +77,20 @@ def init_dsgvo_config():
         shutil.move("/data/tmp.yml", "/data/dsgvo-default.yml")
 
 
+def print_environment(core: OpenModuleCore):
+    core.log.info(f"Service: {core.config.NAME} (version:{core.config.VERSION})")
+    if core.config.DEBUG:
+        core.log.warning(
+            "\n"
+            "       DEBUG MODE is active.\n"
+            "       Deactivate by setting environment variable DEBUG=False.\n"
+            "       Debug is disabled per default when a version string is set or ran inside docker.\n"
+        )
+
+
 def init_openmodule(config, sentry=True, logging=True, dsgvo=True,
                     health_handler: Optional[HealthHandlerType] = None,
-                    context=None) -> OpenModuleCore:
+                    context=None, database=False) -> OpenModuleCore:
     context = context or zmq.Context()
     validate_config_module(config)
 
@@ -82,6 +101,7 @@ def init_openmodule(config, sentry=True, logging=True, dsgvo=True,
 
     if logging:
         init_logging(_core_thread)
+    print_environment(_core_thread)
 
     if sentry:
         init_sentry(_core_thread)
@@ -92,6 +112,9 @@ def init_openmodule(config, sentry=True, logging=True, dsgvo=True,
     if health_handler:
         _core_thread.health.health_handler = health_handler
 
+    if database:
+        _core_thread.init_database()
+
     return _core_thread
 
 
@@ -103,6 +126,9 @@ def shutdown_openmodule():
     global _core_thread
     assert _core_thread, "core thread is not running, did you call init_openmodule(...)?"
 
+    if _core_thread.database:
+        _core_thread.database.shutdown()
+
     _core_thread.context.term()
     _core_thread.join()
 
