@@ -1,9 +1,9 @@
-import logging
 from collections import defaultdict
-from typing import Union, Optional, Callable, DefaultDict, List, Dict, TypeVar, Type
 
+import logging
 import zmq
 from pydantic import ValidationError, BaseModel
+from typing import Union, Optional, Callable, DefaultDict, List, Dict, TypeVar, Type, Generic
 
 from openmodule.models import ZMQMessage
 
@@ -21,38 +21,51 @@ class Listener:
             return message.items() >= self.filter.items()
 
 
-class EventListener(list):
+EventArgs = TypeVar("EventArgs")
+
+
+class EventListener(Generic[EventArgs], list):
     log: Optional[logging.Logger]
 
-    def __init__(self, *args, log=None):
+    def __init__(self, *args, log=None, raise_exceptions=False):
         super().__init__(*args)
+        self.raise_exceptions = raise_exceptions
         self.log = log or logging
 
-    def __call__(self, *args, **kwargs):
+    def __call__(self, *args: EventArgs):
         for f in self:
             try:
-                f(*args, **kwargs)
+                f(*args)
             except zmq.ContextTerminated:
                 raise
             except Exception as e:
-                self.log.exception(e)
+                if self.raise_exceptions:
+                    raise
+                else:
+                    self.log.exception(e)
 
 
-T = TypeVar('T', bound=ZMQMessage)
+ZMQMessageSub = TypeVar('ZMQMessageSub', bound=ZMQMessage)
 
 
 class MessageDispatcher:
-    def __init__(self, name=None):
+    def __init__(self, name=None, raise_validation_errors=False, raise_handler_errors=False):
         """
         :param name: optionally name the dispatcher for logging purposes
+        :param raise_validation_errors: if true and received messages do not match a validation error is raised,
+                                        this is useful in restricive code or testcases
+        :param raise_validation_errors: if true and a message handler raises an exception, the exception is raised,
+                                        this is useful in restricive code or testcases
         """
         self.name = name
         self.log = logging.getLogger(f"{self.__class__.__name__}({self.name})")
         self.listeners: DefaultDict[bytes, List[Listener]] = defaultdict(list)
+        self.raise_validation_errors = raise_validation_errors
+        self.raise_handler_errors = raise_handler_errors
 
     def register_handler(self, topic: Union[bytes, str],
-                         message_class: Type[T],
-                         handler: Callable[[T], None], *,
+                         message_class: Type[ZMQMessageSub],
+                         handler: Callable[[ZMQMessageSub], None], *,
                          filter: Optional[Dict] = None):
         if hasattr(topic, "encode"):
             topic = topic.encode()
@@ -70,15 +83,21 @@ class MessageDispatcher:
     def execute(self, listener: Listener, message: Dict):
         try:
             parsed_message = listener.message_class(**message)
-        except ValidationError:
-            self.log.exception("Invalid message received")
+        except ValidationError as e:
+            if self.raise_validation_errors:
+                raise e from None
+            else:
+                self.log.exception("Invalid message received")
         else:
             try:
                 listener.handler(parsed_message)
             except zmq.ContextTerminated:
                 raise
             except Exception as e:
-                self.log.exception("Error in message handler")
+                if self.raise_handler_errors:
+                    raise e from None
+                else:
+                    self.log.exception("Error in message handler")
 
 
 class SubscribingMessageDispatcher(MessageDispatcher):
@@ -87,8 +106,8 @@ class SubscribingMessageDispatcher(MessageDispatcher):
         self.subscribe = subscribe
 
     def register_handler(self, topic: Union[bytes, str],
-                         message_class: Type[T],
-                         handler: Callable[[T], None], *,
+                         message_class: Type[ZMQMessageSub],
+                         handler: Callable[[ZMQMessageSub], None], *,
                          filter: Optional[Dict] = None):
         self.subscribe(topic)
         return super().register_handler(topic, message_class, handler, filter=filter)
