@@ -9,17 +9,17 @@ import time
 from zmq import ContextTerminated
 
 
-def _thread_wrapper(*args, _run_function, _return_code, **kwargs):
+def _thread_wrapper(run_function, return_code):
     try:
-        _run_function(*args, **kwargs)
+        run_function()
     except (KeyboardInterrupt, ContextTerminated):  # pragma: no cover
         pass
     except Exception as e:  # pragma: no cover
         logging.exception(e)
         sys.stderr.flush()
         time.sleep(1)
-        os._exit(_return_code)
+        os._exit(return_code)
 
 
 def get_thread_wrapper(function, return_code=10):
-    return partial(_thread_wrapper, _run_function=function, _return_code=return_code)
+    return partial(_thread_wrapper, function, return_code)
