@@ -1,16 +1,18 @@
+from typing import Dict, Optional, Any
+from unittest import TestCase
+
 import logging
 import os
 import socket
 import tempfile
 import warnings
-from types import SimpleNamespace
-from unittest import TestCase
-
 from pydantic import ValidationError
+from types import SimpleNamespace
 
 from openmodule import config
 from openmodule.config import validate_config_module
 from openmodule.models import OpenModuleModel
+from openmodule_test.files import temp_file
 
 
 class EnvTestCase(TestCase):
@@ -141,15 +143,10 @@ class ConfigYamlTest(EnvTestCase):
         string: str
 
     def test_path_from_env(self):
-        path = tempfile.mktemp()
-        try:
-            with open(path, "w") as f:
-                f.write("string: not-default")
+        with temp_file("string: not-default") as path:
             self.env(path, "CONFIG_YAML")
             instance = config.yaml(self.ExampleModel)
             self.assertEqual('not-default', instance.string)
-        finally:
-            os.unlink(path)
 
     def test_default_model(self):
         instance = config.yaml(self.ExampleModel)
@@ -164,6 +161,23 @@ class ConfigYamlTest(EnvTestCase):
 
         self.assertIn("wrong with the configuration", str(cm.output))
 
+    def test_yaml_ignores_custom_constructors(self):
+        yaml = """\
+        test: string
+        some: !<CustomObject>
+            a: b
+        """
+
+        class TestModel(OpenModuleModel):
+            test: str
+            some: Optional[Any]
+
+        with temp_file(yaml) as f:
+            model = config.yaml(TestModel, f)
+
+        self.assertIsNone(model.some, msg="Not parsed custom elements must be none")
+        self.assertEqual(model.test, "string")
+
 
 class LegacyConfigSupportTest(EnvTestCase):
     def test_broker_pub(self):
